==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ja/mail.php <==
<?php

return array(
    'a_user_canceled' => 'ユーザーがアイテムリクエストをキャンセルしました。',
    'a_user_requested' => 'ユーザーがアイテムをリクエストしています',
    'accessory_name' => '付属品名:',
    'additional_notes' => '追記:',
    'admin_has_created' => '管理者が:web でアカウントを作成しました。',
    'asset' => '資産:',
    'asset_name' => '資産名:',
    'asset_requested' => '資産リクエスト',
    'asset_tag' => '資産タグ:',
    'assigned_to' => '割り当て先',
    'best_regards' => '敬具',
    'canceled' => 'キャンセル済:',
    'checkin_date' => 'チェックイン日:',
    'checkout_date' => 'チェックアウト日:',
    'click_to_confirm' => ':web account: を有効にする為に、次のリンクをクリックしてください。',
    'click_on_the_link_accessory' => '次のリンクをクリックして、アクセサリーを受け取ったことを確認してください。',
    'click_on_the_link_asset' => '次のリンクをクリックして、資産を受け取ったことを確認してください。',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => '現在の数量',
    'Days' => '日数',
    'days' => '日数',
    'expecting_checkin_date' => 'チェックイン予定日:',
    'expires' => '保証失効日',
    'Expiring_Assets_Report' => '保証切れ資産レポート',
    'Expiring_Licenses_Report' => '有効期限切れのライセンスレポート',
    'hello' => 'こんにちは。',
    'hi' => 'こんにちは',
    'i_have_read' => '私は使用条件を読み、同意し、このアイテムを受け取りました。',
    'item' => 'アイテム:',
    'Item_Request_Canceled' => 'アイテムリクエストがキャンセルされました。',
    'Item_Requested' => 'アイテムをリクエストしました',
    'link_to_update_password' => '次のリンクをクリックして、パスワードを更新してください。 :web password:',
    'login_first_admin' => '以下の新しいログイン情報を使用して、Snipe-ITにログインします。',
    'login' => 'ログイン:',
    'Low_Inventory_Report' => '在庫減レポート',
    'min_QTY' => '分数',
    'name' => '名前',
    'new_item_checked' => 'あなたの名前で新しいアイテムがチェックアウトされました。詳細は以下の通りです。',
    'password' => 'パスワード:',
    'password_reset' => 'パスワードリセット',

    'read_the_terms' => '下記の利用規約をお読みください。',
    'read_the_terms_and_click' => '下部のリンクをクリックして、利用規約に同意して資産を受け取ったことを承認してください。',
    'requested' => '要求済:',
    'reset_link' => 'パスワードリセットのリンク',
    'reset_password' => 'パスワードをリセットするにはここをクリック:',
    'serial' => 'シリアル',
    'supplier' => '仕入先',
    'tag' => 'タグ',
    'test_email' => 'Snipe-ITからのテストメール',
    'test_mail_text' => 'これはSnipe-IT資産管理システムのテストです。あなたがこれを読めているなら、メール機能は動作しています:)',
    'the_following_item' => '次の項目がチェックインされています: ',
    'low_inventory_alert' => '最小在庫を下回っているか、すぐに少なくなる :count のアイテムがあります。',
    'assets_warrantee_alert' => ':threshold 日後に:count の資産の保証期間が終了します。',
    'license_expiring_alert' => ':threshold 日後に:count ライセンスが失効します。',
    'to_reset' => 'パスワードをリセットするには、: web のフォームを完了します:',
    'type' => 'タイプ',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'ユーザ',
    'username' => 'ユーザ名',
    'welcome' => 'ようこそ、 :name さん',
    'welcome_to' => ':web にようこそ!',
    'your_credentials' => 'Snipe-IT クレデンシャル',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ja/mail.php <==
<?php

return [
    'a_user_canceled' => 'ユーザーがアイテムリクエストをキャンセルしました。',
    'a_user_requested' => 'ユーザーがアイテムをリクエストしています',
    'accessory_name' => '付属品名:',
    'additional_notes' => '追記:',
    'admin_has_created' => '管理者が:web でアカウントを作成しました。',
    'asset' => '資産:',
    'asset_name' => '資産名:',
    'asset_requested' => '資産リクエスト',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => '割り当て先',
    'best_regards' => '敬具',
    'canceled' => 'キャンセル済:',
    'checkin_date' => 'チェックイン日:',
    'checkout_date' => 'チェックアウト日:',
    'click_to_confirm' => ':web account: を有効にする為に、次のリンクをクリックしてください。',
    'click_on_the_link_accessory' => '次のリンクをクリックして、アクセサリーを受け取ったことを確認してください。',
    'click_on_the_link_asset' => '次のリンクをクリックして、資産を受け取ったことを確認してください。',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => '現在の数量',
    'Days' => '日数',
    'days' => '日数',
    'expecting_checkin_date' => 'チェックイン予定日:',
    'expires' => '保証失効日',
    'Expiring_Assets_Report' => '保証切れ資産レポート',
    'Expiring_Licenses_Report' => '有効期限切れのライセンスレポート',
    'hello' => 'こんにちは。',
    'hi' => 'こんにちは',
    'i_have_read' => '私は使用条件を読み、同意し、このアイテムを受け取りました。',
    'item' => 'アイテム:',
    'Item_Request_Canceled' => 'アイテムリクエストがキャンセルされました。',
    'Item_Requested' => 'アイテムをリクエストしました',
    'link_to_update_password' => '次のリンクをクリックして、パスワードを更新してください。 :web password:',
    'login_first_admin' => '以下の新しいログイン情報を使用して、Snipe-ITにログインします。',
    'login' => 'ログイン:',
    'Low_Inventory_Report' => '在庫減レポート',
    'min_QTY' => '分数',
    'name' => '名前',
    'new_item_checked' => 'あなたの名前で新しいアイテムがチェックアウトされました。詳細は以下の通りです。',
    'password' => 'パスワード:',
    'password_reset' => 'パスワードリセット',

    'read_the_terms' => '下記の利用規約をお読みください。',
    'read_the_terms_and_click' => '下部のリンクをクリックして、利用規約に同意して資産を受け取ったことを承認してください。',
    'requested' => '要求済:',
    'reset_link' => 'パスワードリセットのリンク',
    'reset_password' => 'パスワードをリセットするにはここをクリック:',
    'serial' => 'シリアル',
    'supplier' => '仕入先',
    'tag' => 'タグ',
    'test_email' => 'Snipe-ITからのテストメール',
    'test_mail_text' => 'これはSnipe-IT資産管理システムのテストです。あなたがこれを読めているなら、メール機能は動作しています:)',
    'the_following_item' => '次の項目がチェックインされています: ',
    'low_inventory_alert' => '最小在庫を下回っているか、すぐに少なくなる :count のアイテムがあります。',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => ':threshold 日後に:count ライセンスが失効します。',
    'to_reset' => 'パスワードをリセットするには、: web のフォームを完了します:',
    'type' => 'タイプ',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'ユーザ',
    'username' => 'ユーザ名',
    'welcome' => 'ようこそ、 :name さん',
    'welcome_to' => ':web にようこそ!',
    'your_credentials' => 'Snipe-IT クレデンシャル',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'あなたの資産を表示',
];
